@@ -3,7 +3,7 @@ check_infile <- function(file) {
     stop("Input filepath must be of length one and not NULL")
   }
 
-  if (!file.exists(file)) {
+  if (!file.exists(file) && !is_url(file)) {
     stop("Input file does not exist")
   }
 }
