@@ -87,7 +87,7 @@ cmsaf.abs <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose
   vars_data <- list(time_bounds = file_data$dimension_data$t)
 
   nc_format <- get_nc_version(nc34)
-  cmsaf_info <- paste0("cmsaf::cmsaf.abs for variable ",
+  cmsaf_info <- paste0("cmsafops::cmsaf.abs for variable ",
                        file_data$variable$name)
 
   time_data <- file_data$dimension_data$t
