@@ -12,6 +12,8 @@
 #'  will be in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of all-time standard deviations
 #'  is written.
@@ -56,6 +58,6 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), file.path(tempdir(),
 #'  "CMSAF_example_file_timsd.nc")))
-timsd <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
-  timx_wrapper("sd", var, infile, outfile, nc34, overwrite, verbose = verbose)
+timsd <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE, nc = NULL) {
+  timx_wrapper("sd", var, infile, outfile, nc34, overwrite, verbose = verbose, nc = nc)
 }
