@@ -127,7 +127,7 @@ trend_advanced <- function(var1, infile1, var2, infile2, outfile, nc34 = 4,
   vars_data <- list(result = result, time_bounds = time_bnds)
 
   nc_format <- get_nc_version(nc34)
-  cmsaf_info <- paste0("cmsaf::trend_advanced for variable ",
+  cmsaf_info <- paste0("cmsafops::trend_advanced for variable ",
                        file_data$variable$name)
 
   time_data <- time_bnds[1, ]
